@@ -732,7 +732,7 @@ class VariableClUpdateRepHost(Variable):
 
 class VariableClUpdateRepHostUrl(Variable):
     type = "list"
-    value = ['git://git.calculate.ru/calculate/%s.git']
+    value = ['git://github.com/calculatelinux/%s.git']
 
 
 class VariableClUpdateProfileDatavars(ReadonlyVariable):
@@ -937,7 +937,7 @@ class VariableClUpdateProfileUrl(Variable):
     profile = "cl_profile_system"
     branch = "cl_update_profile_branch"
     storage = "cl_update_profile_storage"
-    default_url = "git://git.calculate.ru/calculate/distros.git"
+    default_url = "git://github.com/calculatelinux/distros.git"
     profiles_shortname = 'cl_update_profile_shortname'
 
     @property
@@ -996,7 +996,8 @@ class VariableClUpdateProfileUrl(Variable):
         except GitError as e:
             raise VariableError(str(e))
         if not self.Get(self.profiles_shortname):
-            raise VariableError(_("Repository %s has no profiles") % value)
+            raise VariableError(_("Repository %s has no profiles") %
+                value.encode('utf-8'))
 
     def get(self):
         try:
